Python: module TileStache.Goodies.Providers.TileDataOSM

TileStache.Goodies.Providers.TileDataOSM | index

Classes
`` |  | Node Provider SaveableResponse Way
class Node
`` |  | Methods defined here: __init__(self, id, version, timestamp, uid, user, changeset, lat, lon) tag(self, k, v) tags(self)
class Provider
`` |  | Methods defined here: __init__(self, layer, database=None, username=None, password=None, hostname=None) getTypeByExtension(self, extension) `Get mime-type and format by file extension. This only accepts "xml".` renderTile(self, width, height, srs, coord) `Render a single tile, return a SaveableResponse instance.`
class SaveableResponse
`` | `Wrapper class for XML response that makes it behave like a PIL.Image object. TileStache.getTile() expects to be able to save one of these to a buffer.`
| Methods defined here: __init__(self, nodes, ways) save(self, out, format)
class Way
`` |  | Methods defined here: __init__(self, id, version, timestamp, uid, user, changeset) node(self, id) nodes(self) tag(self, k, v) tags(self)

Functions
`` |  | coordinate_bbox(coord, projection) gmtime(...) `gmtime([seconds]) -> (tm_year, tm_mon, tm_mday, tm_hour, tm_min, tm_sec, tm_wday, tm_yday, tm_isdst) Convert seconds since the Epoch to a time tuple expressing UTC (a.k.a. GMT). When 'seconds' is not passed in, convert the current time instead.` prepare_database(db, coord, projection) strftime(...) `strftime(format[, tuple]) -> string Convert a time tuple to a string according to a format specification. See the library reference manual for formatting codes. When the time tuple is not present, current time as returned by localtime() is used.`

Data
`` |  | stderr = <open file '<stderr>', mode 'w'>